import * as asserts from '@std/assert';
import { EPHEMERAL_SERVER, get_ephemeral_listen_server } from './helpers.ts';

Deno.test({
	name: 'get a typescript route with permissions',
	permissions: {
		env: true,
		read: true,
		write: true,
		net: true
	},
	fn: async () => {
		let test_server_info: EPHEMERAL_SERVER | null = null;
		const cwd = Deno.cwd();

		try {
			Deno.chdir('./tests/www');
			test_server_info = await get_ephemeral_listen_server();

			const invalid_response = await fetch(`http://${test_server_info.hostname}:${test_server_info.port}/permissions/test`, {
				method: 'GET'
			});

			const invalid_response_body = await invalid_response.text();

			asserts.assert(!invalid_response.ok);
			asserts.assert(invalid_response_body);
			asserts.assertEquals(invalid_response_body, 'Permission Denied');

			const valid_response = await fetch(`http://${test_server_info.hostname}:${test_server_info.port}/permissions/test`, {
				method: 'GET',
				headers: {
					'x-secret': 'very secret'
				}
			});

			const valid_response_body = await valid_response.text();

			asserts.assert(valid_response.ok);
			asserts.assertEquals(valid_response_body, 'this is secret');
		} finally {
			Deno.chdir(cwd);
			if (test_server_info) {
				await test_server_info?.server?.stop();
			}
		}
	}
});
